#
# $Id$
#   
# Copyright (C) 2003 Kai Sterker <kaisterker@linuxgames.com>
# Part of the Adonthell Project http://adonthell.linuxgames.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY.
#
# See the COPYING file for more details.
#

import item
import adonthell

#
# A torch item. Using will turn it on or off, depending on its
# current state. One charge will last 5 minutes of gametime.
#
class torch (item.item):

    def __init__ (self):
        # -- call constructor of base class
        item.item.__init__ (self)
        
        # -- we need an event_list for storing time_events
        self.Events = adonthell.event_list ()
        
        # -- flag to indicate whether the torch is on or off
        self.IsBurning = 0
        
        # -- Event to keep track of torch consumption
        self.ConsumeEvent = None
    
    def __del__(self):
        self.Events.clear ()
        
    def use (self, user):
        # -- test
        hour = adonthell.gamedate_hour ()
        minute = adonthell.gamedate_minute ()
		
		# -- turn it on
        if self.IsBurning == 0:

            # -- does it have enough charge?
            if self.Charge == 0: return

            # -- test
            print "%02i:%02i Switching %s on." % (hour, minute, self.Name)
            
            if self.ConsumeEvent == None:
                # -- register time event so it is consumed while burning
                #    a charge will last 5 minutes
                self.ConsumeEvent = adonthell.time_event ("5m")

                # -- callback to execute whenever a charge has been used
                #    up.
                self.ConsumeEvent.set_callback (self.on_burn)

                # -- repeat event as often as item has charges
                self.ConsumeEvent.set_repeat ("5m", self.Charge)

                # -- Event lives on C++ side
                self.ConsumeEvent.thisown = 0
            
                # -- register consume event with event_list
                self.Events.add_event (self.ConsumeEvent)
            else:
                # -- resume event
                self.ConsumeEvent.resume ()
            
            self.IsBurning = 1

            # -- while it's burning, make it a lightsource
            self.add_category ("Lightsource")

            # -- start any graphical effects, etc
            # ...
  
        # -- switch it off
        else:
            self.IsBurning = 0
            
            # -- test
            time_left = ((self.Charge * 5.0) - \
                (50 - self.ConsumeEvent.time () + adonthell.gamedate_time ())/10.0)
            print "%02i:%02i Switching %s off. %g Minutes remaining" % \
                (hour, minute, self.Name, max (0,time_left))
            
            # -- make sure event is not repeated
            self.ConsumeEvent.pause ()
            
            # -- not burning, so no lightsource
            self.remove_category ("Lightsource")

            # -- remove any graphical effects, etc
            # ...

    def on_burn (self):
        # -- decrease item's charge
        self.Charge = self.Charge - 1

        # -- test
        hour = adonthell.gamedate_hour ()
        minute = adonthell.gamedate_minute ()
        print "%02i:%02i %s: Charge used up; %i Minutes remaining" % \
            (hour, minute, self.Name, self.Charge * 5)
        
        # -- if no charges left, turn off torch
        if self.Charge == 0:
            # -- the 'use' method will do that for us
            self.use (None)
            
            # -- set to safe state
            self.ConsumeEvent = None
     
    def put_state (self, file):
        # -- save state of parent class
        item.item.put_state (self, file)

        # -- save event list
        self.Events.put_state (file)

        # -- save own parameters
        file.put_bool (self.IsBurning, file)

    def get_state (self, file):
        # -- load state of parent class
        item.item.get_state (self, file)

        # -- load event list
        self.Events.get_state (file)

        # -- load own parameters
        self.IsBurning = file.get_bool (file)

